CloudIgniteSDK class

Constructors

CloudIgniteSDK({required String baseUrl, required String token})
Initializes the CloudIgniteSDK with a base URL and authorization token.

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

deleteFile(String bucket, String filename) Future<String>
Deletes a file from a specific bucket.
getFile(String bucket, String filename) Future<String>
Gets the download URL for a file in a specific bucket.
listFiles(String bucket) Future<String>
Lists files in a specific bucket.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile(String bucket, File file) Future<String>
Uploads a file to a specific bucket.

Operators

operator ==(Object other) bool
The equality operator.
inherited